@@ -2,11 +2,12 @@ import logging
 from datetime import datetime, timedelta
 
 import requests
+from requests.adapters import HTTPAdapter
 from requests.exceptions import RequestException
+from requests.packages.urllib3.util.retry import Retry
 
 from .exceptions import WowApiException, WowApiOauthException
 
-
 logger = logging.getLogger('wowapi')
 logger.addHandler(logging.NullHandler())
 
@@ -15,17 +16,29 @@ class WowApi(object):
 
     __base_url = '{0}.api.blizzard.com'
 
-    def __init__(self, client_id, client_secret):
+    def __init__(self, client_id, client_secret, retry_conn_failures=False):
         self._client_id = client_id
         self._client_secret = client_secret
 
         self._session = requests.Session()
 
+        # Use default retry setup
+        if retry_conn_failures:
+            self.retry_conn_failures()
+
         self._access_tokens = {}
 
     def _utcnow(self):
         return datetime.utcnow()
 
+    def retry_conn_failures(self, total=5, backoff_factor=1,
+                            status_forcelist=[443, 500, 502, 503, 504]):
+        # Allows a user to control how retries function
+        retries = Retry(total=total, backoff_factor=backoff_factor,
+                        status_forcelist=status_forcelist)
+        self._session.mount('http://', HTTPAdapter(max_retries=retries))
+        self._session.mount('https://', HTTPAdapter(max_retries=retries))
+
     def _get_client_credentials(self, region):
         path = '/oauth/token?grant_type=client_credentials&client_id={0}&client_secret={1}'.format(
             self._client_id, self._client_secret
